/* qcam - The Quadratic Camera
 *
 * Copyright (C) 2011 - Willem Jan Palenstijn <wjp@usecode.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef QCAM_LAVC_H
#define QCAM_LAVC_H

#include "video.h"
#include "SDL.h"
#include <vector>
#include <string>
#include <sys/stat.h>

// The extern "C" seems to be missing in the headers
extern "C" {
#include <libavcodec/avcodec.h>
#include <libavdevice/avdevice.h>
#include <libavformat/avformat.h>
#include <libswscale/swscale.h>
}

class LAVC : public VideoPlayer {
public:
	LAVC() { initLAVC(); }
	virtual ~LAVC();

	virtual bool open(const char* filename, SDL_PixelFormat* format); 
	virtual bool getFrame(Uint8* buf, int linesize);

	virtual void getSize(int& width, int& height) const
		{ width = this->width; height = this->height; }

	static std::vector<std::string> findDevices();

private:
	static bool initialized;
	static void initLAVC();

	int width, height;
	PixelFormat format;
	int msPerFrame;
	AVFormatContext *pFormatCtx;
	AVCodecContext *pCodecCtx;
	AVCodec *pCodec;
	AVFrame *pFrame;
	SwsContext* pSWSCtx;
	int videoStream;
	bool v4l2;
};

#endif
